<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation>&lt;p&gt;Este servicio sólo se costea con donaciones de usuarios como tú. &lt;a href=&quot;%1&quot;&gt;Por favor, dona&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation>Versión de %1:
%2</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="180"/>
        <source>Recommended</source>
        <translation>Recomendado</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation>Resolución de problemas y soporte</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation>Informar de un fallo</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation>Cómo desinstalar la aplicación</translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation>No se pudieron encontrar los programas auxiliares. Por favor, comprueba tu instalación</translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation>No se pudo encontrar el agente polkit.</translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation>Cambiar localización</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation>Usar la mejor conexión</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation>Selección manual</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation>Cambiando de gateway...</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation>Sólo localizaciones con puentes</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation>Recomendado</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="43"/>
        <location filename="../components/MainView.qml" line="66"/>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="59"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="73"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="80"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="87"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="111"/>
        <source>Please donate!</source>
        <translation>¡Se agradece una donación!</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="125"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation>Este servicio sólo se costea con donaciones de usuarias como tú. Mantener a flote la VPN cuesta unos 5 euros por persona y mes, pero cada contribución es valiosa. ¿Quieres hacer una donación?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="55"/>
        <source>Turn off the VPN to make changes</source>
        <translation>Desactiva la VPN para hacer cambios</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="71"/>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="105"/>
        <source>Censorship circumvention</source>
        <translation>Circumvención de censura</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="113"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation>Estas técnicas pueden evitar la censura, pero son más lentas. Actívalas sólo cuando lo necesites.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="127"/>
        <source>Use obfs4 bridges</source>
        <translation>Usar puentes obfs4</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="153"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation>El tráfico será ofuscado para saltar bloqueos</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="167"/>
        <source>Use Snowflake</source>
        <translation>Usar Snowflake</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="182"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation>Snowflake necesita Tor instalado en el sistema</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="195"/>
        <source>Transport</source>
        <translation>Transporte</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="203"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation>Con UDP la VPN puede ir más rápido. Podría estar bloqueado en algunas redes.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="216"/>
        <source>Use UDP if available</source>
        <translation>Usar UDP cuando se pueda</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="231"/>
        <source>KCP might work when UDP is blocked on some networks.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="244"/>
        <source>Use KCP if available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>There is a newer version available. </source>
        <translation>Hay disponible una versión nueva.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation>Asegúrate de &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;desinstalar&lt;/a&gt; la versión anterior antes de lanzar el nuevo instalador.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="105"/>
        <source>UPGRADE NOW</source>
        <translation>ACTUALIZAR AHORA</translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="78"/>
        <source>This can take several minutes</source>
        <translation>Esto puede llevar varios minutos</translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation>Comprobando estado...</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation>Connectar a</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <source>Setting up</source>
        <translation>Estableciendo</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="51"/>
        <location filename="../components/VPNState.qml" line="153"/>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="82"/>
        <source>Unsecured
Connection</source>
        <translation>Conexión
Insegura</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="117"/>
        <source>Secured
Connection</source>
        <translation>Conexión
Segura</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 desconectada</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>off</source>
        <translation>apagado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="268"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 on</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="271"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Conectando a %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="274"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Deteniendo %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="277"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 bloqueando Internet</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="284"/>
        <source>pluggable transport connection</source>
        <translation>conexión de transporte conectable</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="286"/>
        <source>connection done</source>
        <translation>conexión realizada</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>doing handshake</source>
        <translation>haciendo negociación</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>handshake done</source>
        <translation>negociación realizada</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>creating one-hop connection</source>
        <translation>creando conexión de un salto</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>requesting status</source>
        <translation>solicitando estado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>loading status</source>
        <translation>cargando estado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>loading keys</source>
        <translation>cargando claves</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="300"/>
        <source>requesting descriptors</source>
        <translation>solicitando descriptores</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="302"/>
        <source>loading descriptors</source>
        <translation>cargando descriptores</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="304"/>
        <source>creating circuit</source>
        <translation>creando circuito</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="306"/>
        <source>done</source>
        <translation>hecho</translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source/>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="140"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation>: una VPN rápida y segura. Potenciada por Bitmask.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="147"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation>No mostrar el ícono en la bandeja del sistema (útil en conjunto con las extensiones de Intérprete de Comandos Gnome, o para controlar la VPN por otros medios).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="154"/>
        <source>Enable Web API.</source>
        <translation>Habilitar la Web API.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="160"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation>Instalar programas auxiliares (sólo en Linux, requiere sudo).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="166"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation>Usar obfs4 para ofuscar el tráfico, si está disponible con el proveedor.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="172"/>
        <source>Enable autostart.</source>
        <translation>Habilitar autoarranque.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="177"/>
        <source>Web API port (default: 8080)</source>
        <translation>Puerto para la API Web (por defecto: 8080)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="180"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation>Iniciar la VPN, &apos;conectada&apos; o bien, &apos;desconectada&apos;.</translation>
    </message>
</context>
</TS>